@@ -47,45 +47,45 @@ class Mmdvm2020(KaitaiStruct):
         self._read()
 
     def _read(self):
-        self.command_prefix = (self._io.read_bytes(4)).decode(u"ASCII")
+        self.command_prefix = (self._io.read_bytes(4)).decode("ASCII")
         _on = self.command_prefix
-        if _on == u"RPTL":
+        if _on == "RPTL":
             self.command_data = Mmdvm2020.TypeRepeaterLoginRequest(
                 self._io, self, self._root
             )
-        elif _on == u"DMRG":
+        elif _on == "DMRG":
             self.command_data = Mmdvm2020.TypeRadioPosition(self._io, self, self._root)
-        elif _on == u"RPTA":
+        elif _on == "RPTA":
             self.command_data = Mmdvm2020.TypeMasterRepeaterAck(
                 self._io, self, self._root
             )
-        elif _on == u"RPTK":
+        elif _on == "RPTK":
             self.command_data = Mmdvm2020.TypeRepeaterLoginResponse(
                 self._io, self, self._root
             )
-        elif _on == u"RPTC":
+        elif _on == "RPTC":
             self.command_data = Mmdvm2020.TypeRepeaterConfigurationOrClosing(
                 self._io, self, self._root
             )
-        elif _on == u"DMRD":
+        elif _on == "DMRD":
             self.command_data = Mmdvm2020.TypeDmrData(self._io, self, self._root)
-        elif _on == u"MSTC":
+        elif _on == "MSTC":
             self.command_data = Mmdvm2020.TypeMasterClosing(self._io, self, self._root)
-        elif _on == u"RPTP":
+        elif _on == "RPTP":
             self.command_data = Mmdvm2020.TypeRepeaterPing(self._io, self, self._root)
-        elif _on == u"RPTO":
+        elif _on == "RPTO":
             self.command_data = Mmdvm2020.TypeRepeaterOptions(
                 self._io, self, self._root
             )
-        elif _on == u"MSTP":
+        elif _on == "MSTP":
             self.command_data = Mmdvm2020.TypeMasterPong(self._io, self, self._root)
-        elif _on == u"RPTS":
+        elif _on == "RPTS":
             self.command_data = Mmdvm2020.TypeRepeaterBeacon(self._io, self, self._root)
-        elif _on == u"MSTN":
+        elif _on == "MSTN":
             self.command_data = Mmdvm2020.TypeMasterNotAccept(
                 self._io, self, self._root
             )
-        elif _on == u"DMRA":
+        elif _on == "DMRA":
             self.command_data = Mmdvm2020.TypeTalkerAlias(self._io, self, self._root)
 
     class TypeMasterPong(KaitaiStruct):
@@ -102,7 +102,7 @@ class Mmdvm2020(KaitaiStruct):
                     b"\x4F\x4E\x47",
                     self.magic,
                     self._io,
-                    u"/types/type_master_pong/seq/0",
+                    "/types/type_master_pong/seq/0",
                 )
             self.repeater_id = self._io.read_u4be()
 
@@ -137,7 +137,7 @@ class Mmdvm2020(KaitaiStruct):
             self.talker_alias_type = KaitaiStream.resolve_enum(
                 Mmdvm2020.TalkerAliasTypes, self._io.read_u1()
             )
-            self.talker_alias = (self._io.read_bytes(8)).decode(u"ASCII")
+            self.talker_alias = (self._io.read_bytes(8)).decode("ASCII")
 
     class TypeRepeaterConfigurationOrClosing(KaitaiStruct):
         def __init__(self, _io, _parent=None, _root=None):
@@ -148,7 +148,7 @@ class Mmdvm2020(KaitaiStruct):
 
         def _read(self):
             _on = self._root.fifth_letter
-            if _on == u"L":
+            if _on == "L":
                 self.data = Mmdvm2020.TypeRepeaterClosing(self._io, self, self._root)
             else:
                 self.data = Mmdvm2020.TypeRepeaterConfiguration(
@@ -190,7 +190,7 @@ class Mmdvm2020(KaitaiStruct):
                     b"\x41\x4B",
                     self.magic,
                     self._io,
-                    u"/types/type_master_not_accept/seq/0",
+                    "/types/type_master_not_accept/seq/0",
                 )
             self.repeater_id = self._io.read_u4be()
 
@@ -218,7 +218,7 @@ class Mmdvm2020(KaitaiStruct):
                     b"\x43\x4B",
                     self.magic,
                     self._io,
-                    u"/types/type_master_repeater_ack/seq/0",
+                    "/types/type_master_repeater_ack/seq/0",
                 )
             self.repeater_id_or_challenge = self._io.read_u4be()
 
@@ -233,7 +233,7 @@ class Mmdvm2020(KaitaiStruct):
             self.magic = self._io.read_bytes(1)
             if not self.magic == b"\x4C":
                 raise kaitaistruct.ValidationNotEqualError(
-                    b"\x4C", self.magic, self._io, u"/types/type_master_closing/seq/0"
+                    b"\x4C", self.magic, self._io, "/types/type_master_closing/seq/0"
                 )
             self.repeater_id = self._io.read_u4be()
 
@@ -288,7 +288,7 @@ class Mmdvm2020(KaitaiStruct):
 
         def _read(self):
             self.repeater_id = self._io.read_u4be()
-            self.options = (self._io.read_bytes_full()).decode(u"ASCII")
+            self.options = (self._io.read_bytes_full()).decode("ASCII")
 
     class TypeRepeaterClosing(KaitaiStruct):
         def __init__(self, _io, _parent=None, _root=None):
@@ -301,7 +301,7 @@ class Mmdvm2020(KaitaiStruct):
             self.magic = self._io.read_bytes(1)
             if not self.magic == b"\x4C":
                 raise kaitaistruct.ValidationNotEqualError(
-                    b"\x4C", self.magic, self._io, u"/types/type_repeater_closing/seq/0"
+                    b"\x4C", self.magic, self._io, "/types/type_repeater_closing/seq/0"
                 )
             self.repeater_id = self._io.read_u4be()
 
@@ -314,21 +314,21 @@ class Mmdvm2020(KaitaiStruct):
 
         def _read(self):
             self.repeater_id = self._io.read_u4be()
-            self.call_sign = (self._io.read_bytes(8)).decode(u"ASCII")
-            self.rx_freq = (self._io.read_bytes(9)).decode(u"ASCII")
-            self.tx_freq = (self._io.read_bytes(9)).decode(u"ASCII")
-            self.tx_power = (self._io.read_bytes(2)).decode(u"ASCII")
-            self.color_code = (self._io.read_bytes(2)).decode(u"ASCII")
-            self.latitude = (self._io.read_bytes(8)).decode(u"ASCII")
-            self.longitude = (self._io.read_bytes(9)).decode(u"ASCII")
-            self.antenna_height_above_ground = (self._io.read_bytes(3)).decode(u"ASCII")
-            self.location = (self._io.read_bytes(20)).decode(u"ASCII")
-            self.description = (self._io.read_bytes(19)).decode(u"ASCII")
-            self.slots = (self._io.read_bytes(1)).decode(u"ASCII")
-            self.url = (self._io.read_bytes(124)).decode(u"ASCII")
-            self.software_id = (self._io.read_bytes(40)).decode(u"ASCII")
-            self.package_id = (self._io.read_bytes(40)).decode(u"ASCII")
-            self.unparsed_data = (self._io.read_bytes_full()).decode(u"ASCII")
+            self.call_sign = (self._io.read_bytes(8)).decode("ASCII")
+            self.rx_freq = (self._io.read_bytes(9)).decode("ASCII")
+            self.tx_freq = (self._io.read_bytes(9)).decode("ASCII")
+            self.tx_power = (self._io.read_bytes(2)).decode("ASCII")
+            self.color_code = (self._io.read_bytes(2)).decode("ASCII")
+            self.latitude = (self._io.read_bytes(8)).decode("ASCII")
+            self.longitude = (self._io.read_bytes(9)).decode("ASCII")
+            self.antenna_height_above_ground = (self._io.read_bytes(3)).decode("ASCII")
+            self.location = (self._io.read_bytes(20)).decode("ASCII")
+            self.description = (self._io.read_bytes(19)).decode("ASCII")
+            self.slots = (self._io.read_bytes(1)).decode("ASCII")
+            self.url = (self._io.read_bytes(124)).decode("ASCII")
+            self.software_id = (self._io.read_bytes(40)).decode("ASCII")
+            self.package_id = (self._io.read_bytes(40)).decode("ASCII")
+            self.unparsed_data = (self._io.read_bytes_full()).decode("ASCII")
 
     class TypeRepeaterPing(KaitaiStruct):
         def __init__(self, _io, _parent=None, _root=None):
@@ -344,7 +344,7 @@ class Mmdvm2020(KaitaiStruct):
                     b"\x49\x4E\x47",
                     self.magic,
                     self._io,
-                    u"/types/type_repeater_ping/seq/0",
+                    "/types/type_repeater_ping/seq/0",
                 )
             self.repeater_id = self._io.read_u4be()
 
@@ -355,6 +355,6 @@ class Mmdvm2020(KaitaiStruct):
 
         _pos = self._io.pos()
         self._io.seek(4)
-        self._m_fifth_letter = (self._io.read_bytes(1)).decode(u"ASCII")
+        self._m_fifth_letter = (self._io.read_bytes(1)).decode("ASCII")
         self._io.seek(_pos)
         return self._m_fifth_letter if hasattr(self, "_m_fifth_letter") else None
