@@ -21,7 +21,7 @@ class DataTransmitProtocol(KaitaiStruct):
 
     class ServiceSpecificTypes(Enum):
         dtp_request = 1
-        data_slice_trasmit = 2
+        data_slice_transmit = 2
         last_data_slice = 3
         dtp_answer = 17
         data_slice_answer = 18
@@ -89,7 +89,7 @@ class DataTransmitProtocol(KaitaiStruct):
             self.file_size = self._io.read_u2be()
             self.file_name = (
                 self._io.read_bytes((self._parent.message_length - 10))
-            ).decode(u"UTF-16LE")
+            ).decode("UTF-16LE")
 
     class DataSliceAnswer(KaitaiStruct):
         def __init__(self, _io, _parent=None, _root=None):
