@@ -29,3 +29,11 @@ class Gpsdata(KaitaiStruct):
         self.longitude = self._io.read_bytes(10)
         self.speed = self._io.read_bytes(3)
         self.direction = self._io.read_bytes(3)
+
+    @property
+    def gps_available(self):
+        if hasattr(self, "_m_gps_available"):
+            return self._m_gps_available if hasattr(self, "_m_gps_available") else None
+
+        self._m_gps_available = (self.gps_status).decode("ASCII") == "A"
+        return self._m_gps_available if hasattr(self, "_m_gps_available") else None
